package fr.univlehavre.projet.carnet;

import fr.univlehavre.projet.entree.*;
import org.junit.jupiter.api.Test;

import java.io.File;
import java.io.IOException;

import static org.junit.jupiter.api.Assertions.*;

class CarnetTest {

	@Test
	void testLectureFichier() throws IOException {
		Carnet c = new Carnet();

		ClassLoader classLoader = getClass().getClassLoader();
		File file = new File(classLoader.getResource("carnet.csv").getFile());

		c.lectureFichier(file.getAbsolutePath());

		assertEquals(5, c.getCompteurEntrees());
	}

	@Test
	void testLectureFichierToutesEntrees() throws IOException {
		Carnet c = new Carnet();

		ClassLoader classLoader = getClass().getClassLoader();
		File file = new File(classLoader.getResource("carnet.csv").getFile());

		c.lectureFichier(file.getAbsolutePath());

		assertEquals("Ecole de sorcellerie Poudlard", c.getEntree(0).toString(null, null));
		assertEquals("M. Albus P. W. B. Dumbledore (Ecole de sorcellerie Poudlard)",
			c.getEntree(1).toString(Presentation.SIMPLE, Sens.PRENOMS_NOMS));
		assertEquals("M. Harry J. Potter (Ecole de sorcellerie Poudlard)",
			c.getEntree(2).toString(Presentation.SIMPLE, Sens.PRENOMS_NOMS));
		assertEquals("Mme Ginny Weasley (Ecole de sorcellerie Rebelle)",
			c.getEntree(3).toString(Presentation.SIMPLE, Sens.PRENOMS_NOMS));

	}

	@Test
	void testLectureFichierConjointApres() throws IOException {
		Carnet c = new Carnet();

		ClassLoader classLoader = getClass().getClassLoader();
		File file = new File(classLoader.getResource("carnet.csv").getFile());

		c.lectureFichier(file.getAbsolutePath());

		Personne p = (Personne) c.getEntree(2);

		assertEquals("Mme Ginny Weasley (Ecole de sorcellerie Rebelle)",
			p.getConjoint().toString(Presentation.SIMPLE, Sens.PRENOMS_NOMS));

	}

	@Test
	void testLectureFichierSocieteApres() throws IOException {
		Carnet c = new Carnet();

		ClassLoader classLoader = getClass().getClassLoader();
		File file = new File(classLoader.getResource("carnet.csv").getFile());

		c.lectureFichier(file.getAbsolutePath());

		Personne p = (Personne) c.getEntree(3);

		assertEquals("Ecole de sorcellerie Rebelle",
			p.getSociete().toString(Presentation.SIMPLE, Sens.PRENOMS_NOMS));

	}
}
